==> kubernetes-model-admissionregistration-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1/RuleWithOperationsBuilder.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class RuleWithOperationsBuilder extends RuleWithOperationsFluentImpl<RuleWithOperationsBuilder> implements VisitableBuilder<RuleWithOperations,RuleWithOperationsBuilder> {

    RuleWithOperationsFluent<?> fluent;
    Boolean validationEnabled;

    public RuleWithOperationsBuilder() {
        this(true);
    }

    public RuleWithOperationsBuilder(Boolean validationEnabled) {
        this(new RuleWithOperations(), validationEnabled);
    }

    public RuleWithOperationsBuilder(RuleWithOperationsFluent<?> fluent) {
        this(fluent, true);
    }

    public RuleWithOperationsBuilder(RuleWithOperationsFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new RuleWithOperations(), validationEnabled);
    }

    public RuleWithOperationsBuilder(RuleWithOperationsFluent<?> fluent,RuleWithOperations instance) {
        this(fluent, instance, true);
    }

    public RuleWithOperationsBuilder(RuleWithOperationsFluent<?> fluent,RuleWithOperations instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiGroups(instance.getApiGroups()); 
        fluent.withApiVersions(instance.getApiVersions()); 
        fluent.withOperations(instance.getOperations()); 
        fluent.withResources(instance.getResources()); 
        fluent.withScope(instance.getScope()); 
        this.validationEnabled = validationEnabled; 
    }

    public RuleWithOperationsBuilder(RuleWithOperations instance) {
        this(instance,true);
    }

    public RuleWithOperationsBuilder(RuleWithOperations instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiGroups(instance.getApiGroups()); 
        this.withApiVersions(instance.getApiVersions()); 
        this.withOperations(instance.getOperations()); 
        this.withResources(instance.getResources()); 
        this.withScope(instance.getScope()); 
        this.validationEnabled = validationEnabled; 
    }

    public RuleWithOperations build() {
        RuleWithOperations buildable = new RuleWithOperations(fluent.getApiGroups(),fluent.getApiVersions(),fluent.getOperations(),fluent.getResources(),fluent.getScope());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        RuleWithOperationsBuilder that = (RuleWithOperationsBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-admissionregistration-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1/RuleWithOperationsBuilder.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class RuleWithOperationsBuilder extends RuleWithOperationsFluentImpl<RuleWithOperationsBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<RuleWithOperations,RuleWithOperationsBuilder> {

    RuleWithOperationsFluent<?> fluent;
    Boolean validationEnabled;

    public RuleWithOperationsBuilder() {
        this(true);
    }

    public RuleWithOperationsBuilder(Boolean validationEnabled) {
        this(new RuleWithOperations(), validationEnabled);
    }

    public RuleWithOperationsBuilder(RuleWithOperationsFluent<?> fluent) {
        this(fluent, true);
    }

    public RuleWithOperationsBuilder(RuleWithOperationsFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new RuleWithOperations(), validationEnabled);
    }

    public RuleWithOperationsBuilder(RuleWithOperationsFluent<?> fluent,RuleWithOperations instance) {
        this(fluent, instance, true);
    }

    public RuleWithOperationsBuilder(RuleWithOperationsFluent<?> fluent,RuleWithOperations instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiGroups(instance.getApiGroups()); 
        fluent.withApiVersions(instance.getApiVersions()); 
        fluent.withOperations(instance.getOperations()); 
        fluent.withResources(instance.getResources()); 
        fluent.withScope(instance.getScope()); 
        this.validationEnabled = validationEnabled; 
    }

    public RuleWithOperationsBuilder(RuleWithOperations instance) {
        this(instance,true);
    }

    public RuleWithOperationsBuilder(RuleWithOperations instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiGroups(instance.getApiGroups()); 
        this.withApiVersions(instance.getApiVersions()); 
        this.withOperations(instance.getOperations()); 
        this.withResources(instance.getResources()); 
        this.withScope(instance.getScope()); 
        this.validationEnabled = validationEnabled; 
    }

    public RuleWithOperations build() {
        RuleWithOperations buildable = new RuleWithOperations(fluent.getApiGroups(),fluent.getApiVersions(),fluent.getOperations(),fluent.getResources(),fluent.getScope());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        RuleWithOperationsBuilder that = (RuleWithOperationsBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
